summaryrefslogtreecommitdiffstats
path: root/src/util/xmlconfig.h
diff options
context:
space:
mode:
authorQiang Yu <[email protected]>2018-08-06 11:19:26 +0800
committerEmil Velikov <[email protected]>2018-08-17 17:16:32 +0100
commit3bbe180b982639554685c997ff51a7cbbf3247e6 (patch)
tree60c412653a73d6ee25471e2a977ad47bfa8e80a8 /src/util/xmlconfig.h
parente8b91e99e9965fa717be25da66fba0cdc3aef5dc (diff)
xmlconfig: add kernel_driver device attribute
This attribute can be used by loader to apply different option to device use specific kernel driver. Signed-off-by: Qiang Yu <[email protected]> Acked-by: Michel Dänzer <[email protected]> Reviewed-by: Emil Velikov <[email protected]>
Diffstat (limited to 'src/util/xmlconfig.h')
-rw-r--r--src/util/xmlconfig.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/src/util/xmlconfig.h b/src/util/xmlconfig.h
index f7683a650e0..cc8c6ef098f 100644
--- a/src/util/xmlconfig.h
+++ b/src/util/xmlconfig.h
@@ -102,10 +102,11 @@ void driParseOptionInfo (driOptionCache *info,
const char *configOptions);
/** \brief Initialize option cache from info and parse configuration files
*
* To be called in <driver>CreateContext. screenNum and driverName select
* device sections. */
void driParseConfigFiles (driOptionCache *cache, const driOptionCache *info,
- int screenNum, const char *driverName);
+ int screenNum, const char *driverName,
+ const char *kernelDriverName);
/** \brief Destroy option info
*
* To be called in <driver>DestroyScreen */
@@ -102,10 +102,11 @@ void driParseOptionInfo (driOptionCache *info,
/** \brief Initialize option cache from info and parse configuration files
*
- * To be called in <driver>CreateContext. screenNum and driverName select
- * device sections. */
+ * To be called in <driver>CreateContext. screenNum, driverName and
+ * kernelDriverName select device sections. */
void driParseConfigFiles (driOptionCache *cache, const driOptionCache *info,